.. _api_fileio_filereader:

Dataset Reading (:mod:`pydicom.filereader`)
===========================================

.. currentmodule:: pydicom.filereader

Functions for reading DICOM datasets from file-likes.

.. autosummary::
   :toctree: generated/

   data_element_generator
   data_element_offset_to_value
   dcmread
   read_dataset
   read_deferred_data_element
   read_dicomdir
   read_file_meta_info
   read_partial
   read_preamble
   read_sequence
   read_sequence_item
